### Name: plot.kde
### Title: Kernel density estimate plot for 1- to 3-dimensional data
### Aliases: plot.kde
### Keywords: hplot

### ** Examples

## univariate example
x <- rnorm.mixt(n=100, mus=1, sigmas=1, props=1)
fhat <- kde(x, h=sqrt(0.09))  
plot(fhat)

## bivariate example
data(unicef)
H.scv <- Hscv(unicef)
fhat <- kde(unicef, H=H.scv)

layout(rbind(c(1,2), c(3,4)))
plot(fhat, display="slice", cont=seq(10,90, by=20), cex=0.3)
plot(fhat, display="slice", ncont=8, drawpoints=FALSE, drawlabels=FALSE)
plot(fhat, display="persp")
plot(fhat, display="image", col=rev(heat.colors(100)))
layout(1)

plot(fhat, display="filled")
  ## filled contour plot not compatible with layout()

## large sample - 10000 sample from bivariate standard normal 
x <- rmvnorm.mixt(10000, c(0,0), diag(2))    
H.pi <- Hpi.diag(x, binned=TRUE)
fhat <- kde(x, H=H.pi, binned=TRUE) 
plot(fhat, drawpoints=FALSE, cont=seq(10,90, by=20))

## Not run: 
##D ## trivariate example
##D mus <- rbind(c(0,0,0), c(-1,1,1))
##D Sigma <- matrix(c(1, 0.7, 0.7, 0.7, 1, 0.7, 0.7, 0.7, 1), nr=3, nc=3) 
##D Sigmas <- rbind(Sigma, Sigma)
##D props <- c(1/2, 1/2)
##D 
##D x <- rmvnorm.mixt(n=1000, mus=mus, Sigmas=Sigmas, props=props)
##D H.pi <- Hpi.diag(x, binned=TRUE, pilot="samse")
##D fhat <- kde(x, H=H.pi, binned=TRUE)  
##D 
##D plot(fhat, origin=c(-3,-3,-3))
## End(Not run)



